@@ -1,12 +1,12 @@
 #!/bin/sh -e
 
 VERSION=$2
-TAR=../doxia-maven-plugin_$VERSION.orig.tar.gz
+TAR=../doxia-maven-plugin_$VERSION.orig.tar.xz
 DIR=doxia-maven-plugin-$VERSION
 TAG=$(echo "doxia-$VERSION" | sed -re's/~(alpha|beta)/-\1-/')
 
 svn export http://svn.apache.org/repos/asf/maven/doxia/doxia/tags/${TAG}/doxia-maven-plugin/ $DIR
-tar -c -z -f $TAR $DIR
+tar -c -J -f $TAR $DIR
 rm -rf $DIR ../$TAG
 
 # move to directory 'tarballs'
